==> haystack-0.6.1.tar.gz: test/io/Tokenizer_test.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.tokenizer_test;

import 'package:haystack/core.dart';
import 'package:haystack/src/io/HaystackToken.dart';
import 'package:haystack/src/io/HaystackTokenizer.dart';
import 'package:test/test.dart';

import '../utils.dart';

void main() {
  group("Tokenizer", () {
    test("Empty", () {
      verifyToks("", []);
    });

    test("Id", () {
      HaystackToken id = HaystackToken.id;
      verifyToks("x", [id, "x"]);
      verifyToks("fooBar", [id, "fooBar"]);
      verifyToks("fooBar1999x", [id, "fooBar1999x"]);
      verifyToks("foo_23", [id, "foo_23"]);
      verifyToks("Foo", [id, "Foo"]);
    });

    test("Ints", () {
      HaystackToken num = HaystackToken.num;
      verifyToks("5", [num, n(5)]);
      verifyToks("0x1234_abcd", [num, n(0x1234abcd)]);
    });

    test("Floats", () {
      HaystackToken num = HaystackToken.num;
      verifyToks("5.0", [num, n(5)]);
      verifyToks("5.42", [num, n(5.42)]);
      verifyToks("123.2e32", [num, n(123.2e32)]);
      verifyToks("123.2e+32", [num, n(123.2e32)]);
      verifyToks("2_123.2e+32", [num, n(2123.2e32)]);
      verifyToks("4.2e-7", [num, n(4.2e-7)]);
    });

    test("NumberWithUnits", () {
      HaystackToken num = HaystackToken.num;
      verifyToks("-40ms", [num, n(-40, "ms")]);
      verifyToks("1sec", [num, n(1, "sec")]);
      verifyToks("5hr", [num, n(5, "hr")]);
      verifyToks("2.5day", [num, n(2.5, "day")]);
      verifyToks("12%", [num, n(12, "%")]);
      verifyToks("987_foo", [num, n(987, "_foo")]);
      verifyToks("-1.2m/s", [num, n(-1.2, "m/s")]);
      verifyToks("12kWh/ft\u00B2", [num, n(12, "kWh/ft\u00B2")]);
      verifyToks("3_000.5J/kg_dry", [num, n(3000.5, "J/kg_dry")]);
    });

    test("Strings", () {
      HaystackToken str = HaystackToken.str;
      verifyToks('""', [str, new HStr("")]);
      verifyToks(r'"x y"', [str, new HStr("x y")]);
      verifyToks(r'"x\"y"', [str, new HStr("x\"y")]);
      verifyToks(
          "\"_\\u012f \\n \\t \\\\_\"", [str, new HStr("_\u012f \n \t \\_")]);
      verifyToks(r'"\$some"', [str, new HStr(r"$some")]);
    });

    test("Date", () {
      HaystackToken date = HaystackToken.date;
      verifyToks("2016-06-06", <Object>[date, new HDate(2016, 6, 6)]);
    });

    test("Time", () {
      HaystackToken time = HaystackToken.time;
      verifyToks("8:30", [time, new HTime(8, 30)]);
      verifyToks("20:15", [time, new HTime(20, 15)]);
      verifyToks("00:00", [time, new HTime(0, 0)]);
      verifyToks("00:00:00", [time, new HTime(0, 0, 0)]);
      verifyToks("01:02:03", [time, new HTime(1, 2, 3)]);
      verifyToks("23:59:59", [time, new HTime(23, 59, 59)]);
      verifyToks("12:00:12.9", [time, new HTime(12, 00, 12, 900)]);
      verifyToks("12:00:12.99", [time, new HTime(12, 00, 12, 990)]);
      verifyToks("12:00:12.999", [time, new HTime(12, 00, 12, 999)]);
      verifyToks("12:00:12.000", [time, new HTime(12, 00, 12, 0)]);
      verifyToks("12:00:12.001", [time, new HTime(12, 00, 12, 1)]);
    });

    test("DateTime", () {
      HaystackToken dt = HaystackToken.dateTime;
      HTimeZone ny = new HTimeZone("New_York", tzOffset(-5, 0));
      HTimeZone utc = HTimeZone.UTC;
      HTimeZone london = new HTimeZone("London");
      verifyToks("2016-01-13T09:51:33-05:00 New_York", [
        dt,
        new HDateTime.fromValues( 2016, 1, 13, 9, 51, 33, ny )
      ]);
      verifyToks("2016-01-13T09:51:33.353-05:00 New_York", [
        dt,
        new HDateTime( new HDate(2016, 1, 13), new HTime(9, 51, 33, 353), ny )
      ]);
      verifyToks("2010-12-18T14:11:30.924Z", [
        dt,
        new HDateTime(
            new HDate(2010, 12, 18), new HTime(14, 11, 30, 924), utc)
      ]);
      verifyToks("2010-12-18T14:11:30.924Z UTC", [
        dt,
        new HDateTime(
            new HDate(2010, 12, 18), new HTime(14, 11, 30, 924), utc)
      ]);
      verifyToks("2010-12-18T14:11:30.924Z London", [
        dt,
        new HDateTime(
            new HDate(2010, 12, 18), new HTime(14, 11, 30, 924), london)
      ]);
      // Apparently PST8PDT is not valid in java?
      //    verifyToks("2015-01-02T06:13:38.701-08:00 PST8PDT", [dt, new HDateTime(new HDate(2015,1,2), new HTime(6,13,38,701), new HTimeZone("PST8PDT"), tzOffset(-8,0))]);
      verifyToks("2010-03-01T23:55:00.013-05:00 GMT+5", [
        dt,
        new HDateTime(new HDate(2010, 3, 1), new HTime(23, 55, 0, 13),
            new HTimeZone("GMT+5", tzOffset(-5, 0)))
      ]);
      verifyToks("2010-03-01T23:55:00.013+10:00 GMT-10 ", [
        dt,
        new HDateTime(new HDate(2010, 3, 1), new HTime(23, 55, 0, 13),
            new HTimeZone("GMT-10", tzOffset(10, 0)))
      ]);
    });

    test("Ref", () {
      HaystackToken ref = HaystackToken.ref;
      verifyToks("@125b780e-0684e169", [ref, new HRef("125b780e-0684e169")]);
      verifyToks("@demo:_:-.~", [ref, new HRef("demo:_:-.~")]);
    });

    test("Uri", () {
      HaystackToken uri = HaystackToken.uri;
      verifyToks("`http://foo/`", [uri, new HUri("http://foo/")]);
      verifyToks("`_ \\n \\\\ \\`_`", [uri, new HUri("_ \n \\\\ `_")]);
    });

    test("Whitespace", () {
      HaystackToken id = HaystackToken.id;
      verifyToks("a\n  b   \rc \r\nd\n\ne", [
        id, "a", HaystackToken.nl, null,
        id, "b", HaystackToken.nl, null,
        id, "c", HaystackToken.nl, null,
        id, "d", HaystackToken.nl, null, HaystackToken.nl, null,
        id, "e"
      ]);
    });
  });
}

void verifyToks(String zinc, List<Object> toks) {
  List<Object> acc = [];
  HaystackTokenizer t = new HaystackTokenizer(zinc.runes);

  while (true) {
    HaystackToken x = t.next();
    expect(x, t.tok);
    if (x == HaystackToken.eof) break;
    acc.add(t.tok);
    acc.add(t.val);
  }

  expect(toks, orderedEquals(acc));
}

==> haystack-1.0.0-dev.0.2.tar.gz: test/io/Tokenizer_test.dart <==
///
/// Copyright (c) 2018, BAS Services & Graphics, LLC.
/// Licensed under the Academic Free License version 3.0
///

library haystack.tokenizer_test;

import 'package:haystack/haystack.dart';
import 'package:haystack/src/io/HaystackToken.dart';
import 'package:haystack/src/io/HaystackTokenizer.dart';
import 'package:test/test.dart';

import '../utils.dart';

void main() {
  group("Tokenizer", () {
    test("Empty", () {
      verifyToks("", []);
    });

    test("Id", () {
      HaystackToken id = HaystackToken.id;
      verifyToks("x", [id, "x"]);
      verifyToks("fooBar", [id, "fooBar"]);
      verifyToks("fooBar1999x", [id, "fooBar1999x"]);
      verifyToks("foo_23", [id, "foo_23"]);
      verifyToks("Foo", [id, "Foo"]);
    });

    test("Ints", () {
      HaystackToken num = HaystackToken.num;
      verifyToks("5", [num, n(5)]);
      verifyToks("0x1234_abcd", [num, n(0x1234abcd)]);
    });

    test("Floats", () {
      HaystackToken num = HaystackToken.num;
      verifyToks("5.0", [num, n(5)]);
      verifyToks("5.42", [num, n(5.42)]);
      verifyToks("123.2e32", [num, n(123.2e32)]);
      verifyToks("123.2e+32", [num, n(123.2e32)]);
      verifyToks("2_123.2e+32", [num, n(2123.2e32)]);
      verifyToks("4.2e-7", [num, n(4.2e-7)]);
    });

    test("NumberWithUnits", () {
      HaystackToken num = HaystackToken.num;
      verifyToks("-40ms", [num, n(-40, "ms")]);
      verifyToks("1sec", [num, n(1, "sec")]);
      verifyToks("5hr", [num, n(5, "hr")]);
      verifyToks("2.5day", [num, n(2.5, "day")]);
      verifyToks("12%", [num, n(12, "%")]);
      verifyToks("987_foo", [num, n(987, "_foo")]);
      verifyToks("-1.2m/s", [num, n(-1.2, "m/s")]);
      verifyToks("12kWh/ft\u00B2", [num, n(12, "kWh/ft\u00B2")]);
      verifyToks("3_000.5J/kg_dry", [num, n(3000.5, "J/kg_dry")]);
    });

    test("Strings", () {
      HaystackToken str = HaystackToken.str;
      verifyToks('""', [str, new HStr("")]);
      verifyToks(r'"x y"', [str, new HStr("x y")]);
      verifyToks(r'"x\"y"', [str, new HStr("x\"y")]);
      verifyToks(
          "\"_\\u012f \\n \\t \\\\_\"", [str, new HStr("_\u012f \n \t \\_")]);
      verifyToks(r'"\$some"', [str, new HStr(r"$some")]);
    });

    test("Date", () {
      HaystackToken date = HaystackToken.date;
      verifyToks("2016-06-06", <Object>[date, new HDate(2016, 6, 6)]);
    });

    test("Time", () {
      HaystackToken time = HaystackToken.time;
      verifyToks("8:30", [time, new HTime(8, 30)]);
      verifyToks("20:15", [time, new HTime(20, 15)]);
      verifyToks("00:00", [time, new HTime(0, 0)]);
      verifyToks("00:00:00", [time, new HTime(0, 0, 0)]);
      verifyToks("01:02:03", [time, new HTime(1, 2, 3)]);
      verifyToks("23:59:59", [time, new HTime(23, 59, 59)]);
      verifyToks("12:00:12.9", [time, new HTime(12, 00, 12, 900)]);
      verifyToks("12:00:12.99", [time, new HTime(12, 00, 12, 990)]);
      verifyToks("12:00:12.999", [time, new HTime(12, 00, 12, 999)]);
      verifyToks("12:00:12.000", [time, new HTime(12, 00, 12, 0)]);
      verifyToks("12:00:12.001", [time, new HTime(12, 00, 12, 1)]);
    });

    test("DateTime", () {
      HaystackToken dt = HaystackToken.dateTime;
      HTimeZone ny = new HTimeZone("New_York", tzOffset(-5, 0));
      HTimeZone utc = HTimeZone.UTC;
      HTimeZone london = new HTimeZone("London");
      verifyToks("2016-01-13T09:51:33-05:00 New_York", [
        dt,
        new HDateTime.fromValues( 2016, 1, 13, 9, 51, 33, ny )
      ]);
      verifyToks("2016-01-13T09:51:33.353-05:00 New_York", [
        dt,
        new HDateTime( new HDate(2016, 1, 13), new HTime(9, 51, 33, 353), ny )
      ]);
      verifyToks("2010-12-18T14:11:30.924Z", [
        dt,
        new HDateTime(
            new HDate(2010, 12, 18), new HTime(14, 11, 30, 924), utc)
      ]);
      verifyToks("2010-12-18T14:11:30.924Z UTC", [
        dt,
        new HDateTime(
            new HDate(2010, 12, 18), new HTime(14, 11, 30, 924), utc)
      ]);
      verifyToks("2010-12-18T14:11:30.924Z London", [
        dt,
        new HDateTime(
            new HDate(2010, 12, 18), new HTime(14, 11, 30, 924), london)
      ]);
      // Apparently PST8PDT is not valid in java?
      //    verifyToks("2015-01-02T06:13:38.701-08:00 PST8PDT", [dt, new HDateTime(new HDate(2015,1,2), new HTime(6,13,38,701), new HTimeZone("PST8PDT"), tzOffset(-8,0))]);
      verifyToks("2010-03-01T23:55:00.013-05:00 GMT+5", [
        dt,
        new HDateTime(new HDate(2010, 3, 1), new HTime(23, 55, 0, 13),
            new HTimeZone("GMT+5", tzOffset(-5, 0)))
      ]);
      verifyToks("2010-03-01T23:55:00.013+10:00 GMT-10 ", [
        dt,
        new HDateTime(new HDate(2010, 3, 1), new HTime(23, 55, 0, 13),
            new HTimeZone("GMT-10", tzOffset(10, 0)))
      ]);
    });

    test("Ref", () {
      HaystackToken ref = HaystackToken.ref;
      verifyToks("@125b780e-0684e169", [ref, new HRef("125b780e-0684e169")]);
      verifyToks("@demo:_:-.~", [ref, new HRef("demo:_:-.~")]);
    });

    test("Uri", () {
      HaystackToken uri = HaystackToken.uri;
      verifyToks("`http://foo/`", [uri, new HUri("http://foo/")]);
      verifyToks("`_ \\n \\\\ \\`_`", [uri, new HUri("_ \n \\\\ `_")]);
    });

    test("Whitespace", () {
      HaystackToken id = HaystackToken.id;
      verifyToks("a\n  b   \rc \r\nd\n\ne", [
        id, "a", HaystackToken.nl, null,
        id, "b", HaystackToken.nl, null,
        id, "c", HaystackToken.nl, null,
        id, "d", HaystackToken.nl, null, HaystackToken.nl, null,
        id, "e"
      ]);
    });
  });
}

void verifyToks(String zinc, List<Object> toks) {
  List<Object> acc = [];
  HaystackTokenizer t = new HaystackTokenizer(zinc.runes);

  while (true) {
    HaystackToken x = t.next();
    expect(x, t.tok);
    if (x == HaystackToken.eof) break;
    acc.add(t.tok);
    acc.add(t.val);
  }

  expect(toks, orderedEquals(acc));
}
